FUNCTION PLANC_M, V, T

;+
; DESCRIPTION:
;    Compute monochromatic Planck radiance given brightness temperature.
;
; USAGE:
;    RESULT = PLANC_M(V, T)
;
; INPUT PARAMETERS:
;    V         Wavenumber (inverse centimeters)
;    T         Brightness temperature (Kelvin)
;
; OUTPUT PARAMETERS:
;    PLANC_M   Planck radiance (milliWatts per square meter per
;              steradian per inverse centimeter)
;-

;- Fundamental Physical Constants from http://physics.nist.gov/cuu/Constants/

;- Planck constant (Joule second)
h = 6.62606896d-34

;- Speed of light in vacuum (meters per second)
c = 299792458.0d

;- Boltzmann constant (Joules per Kelvin)      
k = 1.3806504d-23

;- Derived constants      
c1 = 2.0d * h * c * c
c2 = (h * c) / k
                  
;- Convert wavenumber to inverse meters
vs = (1.0d+2 * v) > 1.0d-10
      
;- Compute Planck radiance
rad = 1.0d5 * (c1 * vs^3) / (exp(c2 * vs / t) - 1.0d)
return, rad > 1.0d-10
            
END
