FUNCTION PLANCK_M, W, T

;+
; DESCRIPTION:
;    Compute monochromatic Planck radiance given brightness temperature.
;
; USAGE:
;    RESULT = PLANCK_M(W, T)
;
; INPUT PARAMETERS:
;    W           Wavelength (microns)
;    T           Brightness temperature (Kelvin)
;
; OUTPUT PARAMETERS:
;    PLANCK_M    Planck radiance (Watts per square meter per steradian
;                per micron)
;-

;- Fundamental Physical Constants from http://physics.nist.gov/cuu/Constants/

;- Planck constant (Joule second)
h = 6.62606896d-34

;- Speed of light in vacuum (meters per second)
c = 299792458.0d

;- Boltzmann constant (Joules per Kelvin)      
k = 1.3806504d-23

;- Derived constants      
c1 = 2.0d * h * c * c
c2 = (h * c) / k
                  
;- Convert wavelength to meters
ws = (1.0d-6 * w) > 1.0d-10
      
;- Compute Planck radiance
rad = 1.0d-6 * (c1 / ws^5) / (exp(c2 / (ws * t)) - 1.0d)
return, rad > 1.0d-10

END
